@@ -18,6 +18,44 @@ from .types import (
 )
 
 
+def resolve_generated_figure_path(figure_path: str) -> str:
+    """Convert generated figure source paths to their output format.
+
+    For figures that are generated during the build process (.mmd, .py, .R),
+    convert the source file extension to the output format (.pdf).
+    This allows users to reference source files in markdown while LaTeX
+    uses the generated output files.
+
+    Args:
+        figure_path: Original figure path from markdown (e.g., "FIGURES/diagram.mmd")
+
+    Returns:
+        Resolved path with output extension (e.g., "FIGURES/diagram.pdf")
+
+    Examples:
+        >>> resolve_generated_figure_path("FIGURES/diagram.mmd")
+        'FIGURES/diagram.pdf'
+        >>> resolve_generated_figure_path("FIGURES/plot.py")
+        'FIGURES/plot.pdf'
+        >>> resolve_generated_figure_path("FIGURES/existing.pdf")
+        'FIGURES/existing.pdf'
+    """
+    # Mapping from source extensions to output extensions
+    GENERATED_EXTENSIONS = {
+        ".mmd": ".pdf",  # Mermaid diagrams → PDF
+        ".py": ".pdf",  # Python scripts → PDF
+        ".R": ".pdf",  # R scripts → PDF
+        ".r": ".pdf",  # R scripts (lowercase) → PDF
+    }
+
+    path = Path(figure_path)
+    if path.suffix in GENERATED_EXTENSIONS:
+        output_ext = GENERATED_EXTENSIONS[path.suffix]
+        return str(path.with_suffix(output_ext))
+
+    return figure_path
+
+
 def convert_figures_to_latex(text: MarkdownContent, is_supplementary: bool = False) -> LatexContent:
     r"""Convert markdown figures to LaTeX figure environments.
 
@@ -175,7 +213,7 @@ def create_latex_figure_environment(
     fit = (_s("fit") or "").lower()
     if _b("fullpage", False):
         fit = "page"
-    singlecol_p = _b("singlecol_floatpage", False)  # keep 1-col [p] only if you *really* want it
+    # singlecol_floatpage deprecated after visual spec update; kept for backward compat (ignored)
 
     # ---------- caption markdown -> LaTeX ----------
     processed_caption = re.sub(r"\*\*([^*]+)\*\*", r"\\textbf{\1}", caption)
@@ -284,28 +322,18 @@ def create_latex_figure_environment(
     # Track original position to determine if user requested dedicated page
     original_position = _strip_br(user_pos)
 
-    # Upgrade to two-column if requested or width ties to \textwidth
+    # Upgrade to two-column if explicitly requested OR width ties to \textwidth (non-p)
     if is_span_req or r"\textwidth" in (user_width or "") or r"\textwidth" in w_expr:
         figure_env, rel_unit, position = "figure*", r"\textwidth", _pos_star(user_pos)
         w_expr, w_kind = _parse_len(user_width, rel_unit)
 
-    # Full-page: dedicated page positioning with tex_position="p"
-    # In two-column documents, figure*[p] (two-column spanning) works better than
-    # figure[p] (single-column) for LaTeX's float placement algorithm.
-    # Default behavior: use figure*[p!] for all dedicated page figures
-    # The ! gives LaTeX stronger guidance to place on dedicated page
-    # Opt-out: set singlecol_floatpage=True to force single-column figure[p]
+    # Dedicated page: use two-column spanning figure* to avoid single-column constraint in 2-col docs
+    # Use [p!] with ! modifier for stronger LaTeX placement guidance
+    # Do NOT set barrier=True - this prevents text from flowing to fill the current page
     if original_position == "p":
-        if singlecol_p:
-            # Explicitly requested single-column [p] figure (rare use case)
-            figure_env, rel_unit, position = "figure", r"\linewidth", "[p!]"
-        else:
-            # Default: use two-column spanning for dedicated page figures
-            # This ensures LaTeX can properly place figures on dedicated pages
-            figure_env, rel_unit, position = "figure*", r"\textwidth", "[p!]"
+        figure_env, rel_unit, position = "figure*", r"\textwidth", "[p!]"
         w_expr, w_kind = _parse_len(user_width, rel_unit)
-        # Auto-enable barrier for [p] figures to ensure one figure per page
-        barrier = True
+        # barrier remains False - allows subsequent text to flow and fill current page
 
     # Landscape
     env_name = ("sidewaysfigure*" if figure_env == "figure*" else "sidewaysfigure") if landscape else figure_env
@@ -328,12 +356,12 @@ def create_latex_figure_environment(
     # Caption width: use \textwidth for two-column figures, \linewidth for single-column
     # For [p] figures, only use full \textwidth if it's a two-column spanning figure (figure*)
     is_twocol_fig = env_name.endswith("*")
-    is_singlecol_floatpage = (position == "[p]") and not is_twocol_fig
+    # is_singlecol_floatpage deprecated
 
     if is_twocol_fig:
         # Two-column spanning figure: use caption_width (default 0.95\textwidth)
         cap_width_for_env = caption_width
-    elif is_singlecol_floatpage:
+    elif False:  # deprecated floatpage branch
         # Single-column dedicated page: use \linewidth to stay within column
         cap_width_for_env = r"\linewidth"
     else:
@@ -379,11 +407,8 @@ def create_latex_figure_environment(
     lines.append("")
     latex_figure = "\n".join(lines)
 
-    # Add clearpage wrapper for dedicated page figures to ensure proper text flow
-    # \vfill fills current page with text, first \clearpage ends current page,
-    # figure gets dedicated page, second \clearpage ensures text resumes after figure
-    if original_position == "p":
-        latex_figure = f"\\vfill\\clearpage\n{latex_figure}\n\\clearpage"
+    # No wrapper needed - LaTeX's float algorithm with [p!] handles dedicated pages correctly
+    # Any clearpage/FloatBarrier wrapper creates white space by preventing subsequent text flow
 
     return latex_figure
 
@@ -454,7 +479,9 @@ def _process_new_figure_format(text: MarkdownContent, is_supplementary: bool = F
             return m.group(0)
 
         try:
-            return create_latex_figure_environment(path, caption_text, attributes, is_supplementary)
+            # Resolve generated figure paths (.mmd, .py, .R) to output format (.pdf)
+            resolved_path = resolve_generated_figure_path(path)
+            return create_latex_figure_environment(resolved_path, caption_text, attributes, is_supplementary)
         except (ValueError, KeyError, TypeError) as e:
             # If LaTeX emission fails due to invalid parameters, log and keep original block
             from ..core.logging_config import get_logger
@@ -527,7 +554,9 @@ def _process_figure_without_attributes(text: MarkdownContent, is_supplementary:
             return m.group(0)
 
         try:
-            return create_latex_figure_environment(path, caption, None, is_supplementary)
+            # Resolve generated figure paths (.mmd, .py, .R) to output format (.pdf)
+            resolved_path = resolve_generated_figure_path(path)
+            return create_latex_figure_environment(resolved_path, caption, None, is_supplementary)
         except (ValueError, KeyError, TypeError) as e:
             from ..core.logging_config import get_logger
 
@@ -614,7 +643,9 @@ def _process_figure_with_attributes(text: MarkdownContent, is_supplementary: boo
 
         # Parse attributes
         attributes = parse_figure_attributes(attr_string)
-        return create_latex_figure_environment(path, caption, attributes, is_supplementary)
+        # Resolve generated figure paths (.mmd, .py, .R) to output format (.pdf)
+        resolved_path = resolve_generated_figure_path(path)
+        return create_latex_figure_environment(resolved_path, caption, attributes, is_supplementary)
 
     # Handle figures with attributes (old format) - both inline and with newlines
     # First try inline format: ![caption](path){attributes}
@@ -637,7 +668,9 @@ def _process_figure_with_attributes(text: MarkdownContent, is_supplementary: boo
 
         # Parse attributes
         attributes = parse_figure_attributes(attr_string)
-        return create_latex_figure_environment(path, combined_caption, attributes, is_supplementary)
+        # Resolve generated figure paths (.mmd, .py, .R) to output format (.pdf)
+        resolved_path = resolve_generated_figure_path(path)
+        return create_latex_figure_environment(resolved_path, combined_caption, attributes, is_supplementary)
 
     text = re.sub(
         r"!\[([^\]]*)\]\(([^)]+)\)\s*\n\s*\{([^}]+)\}\s*(.*?)(?=\n\n|\Z)",
