@@ -411,23 +411,60 @@ def process_template_replacements(template_content, yaml_metadata, article_md):
     template_content = template_content.replace("<PY-RPL:BIBLIOGRAPHY>", bibliography_section)
 
     # Extract content sections from markdown
-    content_sections = extract_content_sections(article_md)
+    content_sections, section_order = extract_content_sections(article_md)
 
     # Replace content placeholders with extracted sections
     template_content = template_content.replace("<PY-RPL:ABSTRACT>", content_sections.get("abstract", ""))
 
+    # Handle Methods section based on methods_placement configuration
+    methods_placement = yaml_metadata.get("methods_placement", "after_bibliography")
+    methods_content = content_sections.get("methods", "").strip()
+
+    # Map numeric values to string options for backward compatibility
+    numeric_mapping = {
+        1: "after_intro",
+        2: "after_results",
+        3: "after_discussion",
+        4: "after_bibliography",
+    }
+
+    if isinstance(methods_placement, int) and methods_placement in numeric_mapping:
+        methods_placement = numeric_mapping[methods_placement]
+
+    # Validate methods_placement value and fallback to "after_bibliography" if invalid
+    valid_placements = ["after_intro", "after_results", "after_discussion", "after_bibliography"]
+    if methods_placement not in valid_placements:
+        import sys
+
+        print(
+            f'⚠️  Warning: Invalid methods_placement value "{methods_placement}". '
+            f'Using "after_bibliography" as fallback. Valid options: {", ".join(valid_placements)} or numeric values 1-4',
+            file=sys.stderr,
+        )
+        methods_placement = "after_bibliography"
+
     # Handle main/introduction section with proper header and include all custom sections
     main_section_parts = []
 
+    # Build main section in standard order
     if content_sections.get("introduction"):
         # If there's an introduction section, use it with "Introduction" header
         main_section_content = content_sections["introduction"]
         main_section_parts.append(f"\\section*{{Introduction}}\n{main_section_content}")
+
+        # after_intro mode: insert Methods right after Introduction
+        if methods_placement == "after_intro" and methods_content:
+            main_section_parts.append(f"\\section*{{Methods}}\n{methods_content}")
+
     elif content_sections.get("main"):
         # If there's a main section (but no introduction), use it with "Main" header
         main_section_content = content_sections["main"]
         main_section_parts.append(f"\\section*{{Main}}\n{main_section_content}")
 
+        # after_intro mode: insert Methods after Main section if no Introduction exists
+        if methods_placement == "after_intro" and methods_content:
+            main_section_parts.append(f"\\section*{{Methods}}\n{methods_content}")
+
     # Include all custom sections (sections that don't map to standard academic paper sections)
     standard_sections = {
         "abstract",
@@ -442,6 +479,7 @@ def process_template_replacements(template_content, yaml_metadata, article_md):
         "manuscript_preparation",
         "author_contributions",
         "acknowledgements",
+        "competing_interests",
         "funding",
     }
 
@@ -454,36 +492,6 @@ def process_template_replacements(template_content, yaml_metadata, article_md):
     if custom_sections:
         main_section_parts.extend(custom_sections)
 
-    # Handle Methods section based on methods_placement configuration
-    methods_placement = yaml_metadata.get("methods_placement", "inline")
-    methods_content = content_sections.get("methods", "").strip()
-
-    # Map numeric values to string options for backward compatibility
-    numeric_mapping = {
-        1: "inline",
-        2: "after_results",
-        3: "after_bibliography",
-    }
-
-    if isinstance(methods_placement, int) and methods_placement in numeric_mapping:
-        methods_placement = numeric_mapping[methods_placement]
-
-    # Validate methods_placement value and fallback to "inline" if invalid
-    valid_placements = ["inline", "after_results", "after_bibliography"]
-    if methods_placement not in valid_placements:
-        import sys
-
-        print(
-            f'⚠️  Warning: Invalid methods_placement value "{methods_placement}". '
-            f'Using "inline" as fallback. Valid options: {", ".join(valid_placements)} or numeric values 1-3',
-            file=sys.stderr,
-        )
-        methods_placement = "inline"
-
-    if methods_placement == "inline" and methods_content:
-        # Methods should appear inline in content - add it to main section with header
-        main_section_parts.append(f"\\section*{{Methods}}\n{methods_content}")
-
     # Combine all parts into the final main section
     main_section = "\n\n".join(main_section_parts) if main_section_parts else ""
 
@@ -521,6 +529,12 @@ def process_template_replacements(template_content, yaml_metadata, article_md):
     else:
         template_content = template_content.replace("<PY-RPL:METHODS-AFTER-RESULTS>", "")
 
+    if methods_placement == "after_discussion" and methods_content:
+        methods_section = f"\\section*{{Methods}}\n{methods_content}"
+        template_content = template_content.replace("<PY-RPL:METHODS-AFTER-DISCUSSION>", methods_section)
+    else:
+        template_content = template_content.replace("<PY-RPL:METHODS-AFTER-DISCUSSION>", "")
+
     if methods_placement == "after_bibliography" and methods_content:
         methods_section = f"\\section*{{Methods}}\n{methods_content}"
         template_content = template_content.replace("<PY-RPL:METHODS-AFTER-BIBLIOGRAPHY>", methods_section)
@@ -568,6 +582,16 @@ def process_template_replacements(template_content, yaml_metadata, article_md):
         acknowledgements_block = ""
     template_content = template_content.replace("<PY-RPL:ACKNOWLEDGEMENTS-BLOCK>", acknowledgements_block)
 
+    # Competing Interests
+    competing_interests = content_sections.get("competing_interests", "").strip()
+    if competing_interests:
+        competing_interests_block = f"""\\begin{{interests}}
+{competing_interests}
+\\end{{interests}}"""
+    else:
+        competing_interests_block = ""
+    template_content = template_content.replace("<PY-RPL:COMPETING-INTERESTS-BLOCK>", competing_interests_block)
+
     template_content = template_content.replace("<PY-RPL:FUNDING>", content_sections.get("funding", ""))
     # Generate manuscript preparation content
     manuscript_prep_content = content_sections.get("manuscript_preparation", "")
