@@ -102,8 +102,6 @@ class TestPyPIPackageIntegration:
                                 "rxiv_maker.cli",
                                 "init",
                                 str(manuscript_dir),
-                                "--template",
-                                "basic",
                                 "--no-interactive",
                             ],
                             cwd=original_cwd,  # Run from original directory
@@ -117,8 +115,6 @@ class TestPyPIPackageIntegration:
                                 "rxiv_maker.cli",
                                 "init",
                                 str(manuscript_dir),
-                                "--template",
-                                "basic",
                                 "--no-interactive",
                             ],
                             cwd=original_cwd,
@@ -130,8 +126,6 @@ class TestPyPIPackageIntegration:
                             "rxiv",
                             "init",
                             "/workspace/TEST_MANUSCRIPT",
-                            "--template",
-                            "basic",
                             "--no-interactive",
                             "--force",
                         ],
